From: Matt Hsu <matt_hsu@openmoko.org>
Date: Mon, 5 Jan 2009 16:50:56 +0800

add initalization of jbt6k74 on gta03

Signed-off-by: Matt Hsu <matt_hsu@openmoko.org>
---
 arch/arm/mach-s3c6410/include/mach/om-gta03.h |    1 +
 arch/arm/mach-s3c6410/mach-om-gta03.c         |   65 +++++++++++++++++++++++-
 2 files changed, 63 insertions(+), 3 deletions(-)

diff --git a/arch/arm/mach-s3c6410/include/mach/om-gta03.h b/arch/arm/mach-s3c6410/include/mach/om-gta03.h
index 17a07dd..6a4d3a0 100644
--- a/arch/arm/mach-s3c6410/include/mach/om-gta03.h
+++ b/arch/arm/mach-s3c6410/include/mach/om-gta03.h
@@ -51,6 +51,7 @@ extern struct pcf50633_platform_data om_gta03_pcf_pdata;
 
 #define GTA03_GPIO_NWLAN_POWER		S3C64XX_GPK(0)
 #define GTA03_GPIO_MODEN_ON		S3C64XX_GPK(2)
+#define GTA03_GPIO_LCD_RESET		S3C64XX_GPK(6)
 
 #define GTA03_GPIO_TP_RESET		S3C64XX_GPM(0)
 #define GTA03_GPIO_GPS_LNA_EN		S3C64XX_GPM(2)
diff --git a/arch/arm/mach-s3c6410/mach-om-gta03.c b/arch/arm/mach-s3c6410/mach-om-gta03.c
index 6ff3aad..1ad1bf8 100644
--- a/arch/arm/mach-s3c6410/mach-om-gta03.c
+++ b/arch/arm/mach-s3c6410/mach-om-gta03.c
@@ -29,6 +29,7 @@
 #include <linux/fb.h>
 #include <linux/delay.h>
 #include <linux/lis302dl.h>
+#include <linux/spi/spi_bitbang.h>
 
 #include <video/platform_lcd.h>
 
@@ -39,6 +40,7 @@
 #include <mach/hardware.h>
 #include <mach/map.h>
 #include <mach/regs-fb.h>
+#include <mach/spi-gpio.h>
 
 #include <asm/irq.h>
 #include <asm/mach-types.h>
@@ -58,6 +60,7 @@
 #include <linux/i2c.h>
 #include <linux/backlight.h>
 #include <linux/regulator/machine.h>
+#include <linux/jbt6k74.h>
 
 #include <mach/om-gta03.h>
 
@@ -280,8 +283,8 @@ static struct s3c_fb_pd_win om_gta03_fb_win0 = {
 		.lower_margin	= 16,
 		.hsync_len	= 8,
 		.vsync_len	= 2,
-		.xres		= 640,
-		.yres		= 480,
+		.xres		= 480,
+		.yres		= 640,
 	},
 	.max_bpp	= 32,
 	.default_bpp	= 16,
@@ -294,6 +297,62 @@ static struct s3c_fb_platdata om_gta03_lcd_pdata __initdata = {
 	.vidcon1	= VIDCON1_INV_HSYNC | VIDCON1_INV_VSYNC,
 };
 
+static void gta03_jbt6k74_reset(int devidx, int level)
+{
+	gpio_direction_output(GTA03_GPIO_LCD_RESET, 1);
+}
+
+static void gta03_jbt6k74_probe_completed(struct device *dev)
+{
+	platform_device_register(&s3c_device_fb);
+}
+
+const struct jbt6k74_platform_data gta03_jbt6k74_pdata = {
+	.reset		= gta03_jbt6k74_reset,
+	.probe_completed = gta03_jbt6k74_probe_completed,
+};
+
+static struct spi_board_info gta03_spi_board_info[] = {
+	{
+		.modalias	= "jbt6k74",
+		.platform_data	= &gta03_jbt6k74_pdata,
+		/* controller_data */
+		/* irq */
+		.max_speed_hz	= 10 * 1000 * 1000,
+		.bus_num	= 1,
+		/* chip_select */
+	},
+};
+
+static void spi_gpio_cs(struct s3c64xx_spigpio_info *spi, int csidx, int cs)
+{
+	switch (cs) {
+	case BITBANG_CS_ACTIVE:
+		gpio_direction_output(GTA03_GPIO_LCM_CS, 0);
+		break;
+	case BITBANG_CS_INACTIVE:
+		gpio_direction_output(GTA03_GPIO_LCM_CS, 1);
+		break;
+	}
+}
+
+static struct s3c64xx_spigpio_info spi_gpio_cfg = {
+	.pin_clk	= GTA03_GPIO_LCM_CLK,
+	.pin_mosi	= GTA03_GPIO_LCM_MOSI,
+	//.pin_miso	= /* no pinout to MISO */
+	.board_size	= ARRAY_SIZE(gta03_spi_board_info),
+	.board_info	= gta03_spi_board_info,
+	.chip_select	= &spi_gpio_cs, 
+	.num_chipselect = 1,   /* FIXME: ?? */
+};
+
+struct platform_device gta03_device_spi_lcm = {
+	.name		  = "spi_s3c64xx_gpio",
+	.id		  = 1,
+	.dev = {
+		.platform_data = &spi_gpio_cfg,
+	},
+};
 
 struct map_desc om_gta03_6410_iodesc[] = {};
 
@@ -548,9 +607,9 @@ static struct i2c_board_info om_gta03_i2c_devs[] __initdata = {
 
 
 static struct platform_device *om_gta03_devices[] __initdata = {
-	&s3c_device_fb,
 	&s3c_device_i2c0,
 	&s3c_device_hsmmc1, /* SDIO to WLAN */
+	&gta03_device_spi_lcm,
 };
 
 
-- 
1.5.5.1

